@@ -49,7 +49,7 @@ function gen_sim_where()
 	if($_REQUEST['chkAll0']) {
 		$where=" where 1";
 	}else if($_REQUEST['sim_name']){
-		$where=" where sim_name='".$_REQUEST['sim_name']."' ";
+		$where=" where sim_name in (".$_REQUEST['sim_name'].") ";
 	}else {
 		$id=get_id();
 		if(!$id) WriteErrMsg("Not choose one SIM Slot!");
@@ -212,7 +212,7 @@ if(isset($_GET['action'])) {
 	}
 	elseif($action=="savemoremodify")
 	{
-		print_r($_POST);
+		//print_r($_POST);
 		$password=$_POST['Password'];
 		$name=$_POST['name'];
 		$team_id=$_POST['team_id'];
@@ -223,8 +223,9 @@ if(isset($_GET['action'])) {
 		$remain_time=$_POST['remain_time'];
 		$time_unit=$_POST['time_unit'];
 		$imei_mode=$_POST['imei_mode'];
-		//$where=gen_sim_where();
+		$where=gen_sim_where();
 		if($remain_time == "" || $remain_time < -1) $remain_time=-1;
+		if($_POST[time_limit] == "" || $_POST[time_limit] < -1) $_POST[time_limit]=-1;
                 if($_POST[no_ring_limit] == "" || $_POST[no_ring_limit] < -1) $_POST[no_ring_limit]=-1;
                 if($_POST[no_answer_limit] == "" || $_POST[no_answer_limit] < -1) $_POST[no_answer_limit]=-1;
                 if($_POST[short_call_limit] == "" || $_POST[short_call_limit] < -1) $_POST[short_call_limit]=-1;
@@ -240,18 +241,18 @@ if(isset($_GET['action'])) {
 			$sql="UPDATE sim SET ";
 			if($_POST['team_id_modify']) $sql.="sim_team_id='$team_id',";
 			if($_POST['imei_mode_modify']) $sql.="imei_mode='$imei_mode',";
-			if($_POST['time_limit_modify']) $sql.="time_limit='$_POST[time_limit]',";
-			if($_POST['count_limit_modify']) $sql.="count_limit='$_POST[count_limit]',";
-			if($_POST['no_connected_limit_modify']) $sql.="no_connected_limit='$_POST[no_connected_limit]',";
+			if($_POST['time_limit_modify']) $sql.="time_limit='$_POST[time_limit]',remain_time='$_POST[time_limit]',";
+			if($_POST['count_limit_modify']) $sql.="count_limit='$_POST[count_limit]',count_remain=$_POST[count_limit],";
+			if($_POST['no_connected_limit_modify']) $sql.="no_connected_limit='$_POST[no_connected_limit]',no_connected_remain=$_POST[no_connected_limit],";
 			if($_POST['time_unit_modify']) $sql.="time_unit='$time_unit',";
 			if($_POST['no_ring_modify']) $sql.="no_ring_limit='$_POST[no_ring_limit]',no_ring_disable='$_POST[no_ring_disable]',";
 			if($_POST['no_answer_modify']) $sql.="no_answer_limit='$_POST[no_answer_limit]',no_answer_disable='$_POST[no_answer_disable]',";
 			if($_POST['short_call_modify']) $sql.="short_call_limit='$_POST[short_call_limit]',short_call_disable='$_POST[short_call_disable]',";
 			if($_POST['short_time_modify']) $sql.="short_time='$_POST[short_time]',";
 			if($_POST['dev_disable_modify']) $sql.="dev_disable='$dev_disable',";
-			if($_POSY['auto_reset_remain_modify']) $sql.="auto_reset_remain='$_POST[auto_reset_remain]'";
-			if($_POSY['auto_reset_remain_s_modify']) $sql.="auto_reset_remain_s='$_POST[auto_reset_remain_s]'";
-			$sql.="sim_login=sim_login where sim_name in ($sim_name)";
+			if($_POSY['auto_reset_remain_modify']) $sql.="auto_reset_remain='$_POST[auto_reset_remain]',";
+			if($_POSY['auto_reset_remain_s_modify']) $sql.="auto_reset_remain_s='$_POST[auto_reset_remain_s]',";
+			$sql.="sim_login=sim_login $where";
 			$db->query($sql);
 
                         $query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name $where");
@@ -319,6 +320,34 @@ if(isset($_GET['action'])) {
 		sendto_xchanged($send);
 		WriteSuccessMsg("<br><li>The commond is sended to Server.</li>","?bank_name=$_REQUEST[bank_name]&group_id=$_REQUEST[group_id]&order=$order_type&order_key=$order_key");
 	}
+	else if($action=="set_imei_db"){
+		$where=gen_sim_where();
+
+		$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name $where");
+		$num=$db->num_rows($query);
+		$query0=$db->query("select id,imei from imei_db order by used limit $num");
+		while($row0=$db->fetch_array($query0)) {
+			$imei_db[]=$row0;
+		}
+		$i=0;
+		while($row=$db->fetch_array($query)) {
+			if($imei_db[$i]){
+				$row['imei_mode']==2;
+				$row['imei']=$imei_db[$i]['imei'];
+				$imei_db[$i]['sim_name']=$row['sim_name'];
+				$log.="<br>SIM Slot:$row[sim_name] Set IMEI:$row[imei]";
+				$send[]=my_pack($row, SIM_ADD);
+				$db->query("update imei_db set sim_name='$row[sim_name]',used=used+1,used_time=now() where id=".$imei_db[$i]['id']);
+				$db->query("update sim set imei_mode=2, imei='$row[imei]' where id=$row[id]");
+			}
+			else {
+				$log.="<br>SIM Slot:$row[sim_name] not find IMEI from database";
+			}
+			$i++;
+		}
+		sendto_xchanged($send);
+		WriteSuccessMsg("<br><li>The commond is sended to Server.$log</li>","?bank_name=$_REQUEST[bank_name]&group_id=$_REQUEST[group_id]&order=$order_type&order_key=$order_key");
+	}
 	else $action="main";
 
 	}
@@ -430,7 +459,7 @@ if(isset($_GET['action'])) {
 				$row['remain_state'] = '<font color="#FF8000">Warning</font>';
 			}
 			$row['limit_state'] = '<font color="#00FF00">Enough</font>';
-			if(($row['no_ring_remain'] >= $row['no_ring_limit'] && $row['no_ring_limit']!=-1)|| ($row['no_answer_remain']>=$row['no_answer_limit'] && $row['no_answer_limit']!=-1) || ($row['short_call_remain'] > $row['short_call_limit'] && $row['short_call_limit']!=-1)){
+			if(($row['no_ring_remain'] >= $row['no_ring_limit'] && $row['no_ring_limit']!=-1)|| ($row['no_answer_remain']>=$row['no_answer_limit'] && $row['no_answer_limit']!=-1) || ($row['short_call_remain'] >= $row['short_call_limit'] && $row['short_call_limit']!=-1)){
 				$row['limit_state'] = '<font color="#FF8000">Warning</font>';
 			}
 			$rsdb[]=$row;
