@@ -43,11 +43,11 @@ if(isset($_GET['action'])) {
 		//echo $rcount;
 		$fenye=showpage2("sim_team.php?action=recv&id=$id&",$page,$count,$perpage,true,true,"编","myform","boxs");
 		//if(_GET)
-		$query=$db->query("(select sim.*,sim_team_name, 1 as 'in' from sim left join sim_team using (sim_team_id) where sim.sim_team_id=$id order by sim.id )
+		$query=$db->query("(select sim.*,sim_team_name, 1 as 'in' from sim left join sim_team using (sim_team_id) where sim.sim_team_id=$id order by sim_name limit 999999)
 				union 
-				(select *,NULL,0 from sim where sim_team_id=0 order by id ) 
+				(select *,NULL,0 from sim where sim_team_id=0 order by sim_name limit 999999 ) 
 				union
-				(select sim.*,sim_team_name,2 from sim left join sim_team using (sim_team_id) where sim.sim_team_id!=0 and sim.sim_team_id!=$id order by id ) 
+				(select sim.*,sim_team_name,2 from sim left join sim_team using (sim_team_id) where sim.sim_team_id!=0 and sim.sim_team_id!=$id order by sim_name limit 999999 ) 
 				LIMIT $start_limit,$perpage");
 
 		//$query=$db->query("SELECT receiver.*,groups.id as groupsid,groups.name as groupsname  FROM receiver LEFT JOIN (groups join recvgroup on groups.id=recvgroup.groupsid) ON recvgroup.recvid = receiver.id  ORDER BY groups.id=$id DESC,id DESC LIMIT $start_limit,$perpage");
@@ -243,11 +243,11 @@ else if($action=="grecv"){
                 //echo $rcount;
                 $fenye=showpage2("sim_team.php?action=grecv&id=$id&",$page,$count,$perpage,true,true,"编","myform","boxs");
                 //if(_GET)
-                $query=$db->query("(select device_line.*,sim_team_name, 1 as 'in' from device_line left join sim_team on sim_team.sim_team_id=device_line.goip_team_id where device_line.goip_team_id=$id order by line_name ASC)
+                $query=$db->query("(select device_line.*,sim_team_name, 1 as 'in' from device_line left join sim_team on sim_team.sim_team_id=device_line.goip_team_id where device_line.goip_team_id=$id order by line_name ASC limit 999999)
                                 union 
-                                (select *,NULL,0 from device_line where goip_team_id=0 order by line_name ASC) 
+                                (select *,NULL,0 from device_line where goip_team_id=0 order by line_name ASC limit 999999) 
                                 union
-                                (select device_line.*,sim_team_name,2 from device_line left join sim_team on sim_team.sim_team_id=device_line.goip_team_id where device_line.goip_team_id!=0 and device_line.goip_team_id!=$id order by line_name ASC)
+                                (select device_line.*,sim_team_name,2 from device_line left join sim_team on sim_team.sim_team_id=device_line.goip_team_id where device_line.goip_team_id!=0 and device_line.goip_team_id!=$id order by line_name ASC limit 999999)
                                         LIMIT $start_limit,$perpage");
 
                 //$query=$db->query("SELECT receiver.*,groups.id as groupsid,groups.name as groupsname  FROM receiver LEFT JOIN (groups join recvgroup on groups.id=recvgroup.groupsid) ON recvgroup.recvid = receiver.id  ORDER BY groups.id=$id DESC,id DESC LIMIT $start_limit,$perpage");
