@@ -282,6 +282,39 @@
 	@$db->updatequery("ALTER TABLE  `system` CHANGE  `auto_disable_s_call_msg`  `auto_disable_s_call_msg` VARCHAR( 256 ) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT 'Unassigned (unallocated) number'");
 
 	@$db->updatequery("ALTER TABLE `sim` ADD `last_call_msg` varchar(256) NOT NULL");
+
+/*1.6*/
+	if(!$rs || $rs[0] < 106){
+		@$db->updatequery("update `system` set `version`='106'");
+		@$db->updatequery("CREATE TABLE IF NOT EXISTS `auto_simulation` (
+  `id` int(11) NOT NULL auto_increment,
+  `name` varchar(64) character set utf8 NOT NULL,
+  `disable` tinyint(1) NOT NULL default '0',
+  `dial_num` varchar(256) NOT NULL,
+  `period_min` int(11) NOT NULL,
+  `period_max` int(11) NOT NULL,
+  `talk_time_min` int(11) NOT NULL,
+  `talk_time_max` int(11) NOT NULL,
+  `next_time` datetime NOT NULL,
+  `last_time` datetime NOT NULL,
+  PRIMARY KEY  (`id`)
+) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;");
+		@$db->updatequery("ALTER TABLE `device_line` ADD `auto_simulation_id` int(11) NOT NULL");
+		@$db->updatequery("ALTER TABLE `device_line` ADD `next_auto_dial_time` int(10) unsigned NOT NULL");
+		@$db->updatequery("ALTER TABLE `device_line` ADD `last_auto_dial_time` datetime NOT NULL");
+		@$db->updatequery("ALTER TABLE `device_line` ADD INDEX (`auto_simulation_id`)");
+	}
+	@$db->updatequery("CREATE TABLE IF NOT EXISTS `imei_db` (
+  `id` int(11) NOT NULL auto_increment,
+  `imei` varchar(15) NOT NULL,
+  `sim_name` int(11) NOT NULL default '0',
+  `used` int(11) NOT NULL default '0',
+  `used_time` datetime NOT NULL,
+  PRIMARY KEY  (`id`),
+  KEY `sim_name` (`sim_name`),
+  KEY `used` (`used`)
+) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1;");
+
 	echo "update done! <a href=''  target=_top>Return</a>";
 
 
